@@ -20,17 +20,13 @@ linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
    if (min(dim(as.data.frame(var_name)) == 1) != 1) {
        stop("'var_name' must have defined name of the linearized variable")}
 
-   # check 'p'
-   p <- percentage
-   if(length(p) != 1 |  any(!is.numeric(p) | p < 0 | p > 100)) {
-          stop("'percentage' must be a numeric value in [0, 100]")  }
-
-   # check 'order_quant'
-   oq <- order_quant
-   if(length(oq) != 1 | any(!is.numeric(oq) | oq < 0 | oq > 100)) {
-          stop("'order_quant' must be a numeric value in [0, 100]")  }
-
    if (checking) {
+          percentage <- check_var(vars = percentage, varn = "percentage",
+                                  varntype = "numeric0100")
+
+          order_quant <- check_var(vars = order_quant, varn = "order_quant",
+                                   varntype = "numeric0100") 
+
           Y <- check_var(vars = Y, varn = "Y", dataset = dataset,
                          ncols = 1, isnumeric = TRUE,
                          isvector = TRUE, grepls = "__")
@@ -60,8 +56,7 @@ linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
                            ncols = 1, Ynrow = Ynrow, ischaracter = TRUE,
                            periods = period)
       }
-
-
+  
   ## computations
   ind0 <- rep.int(1, length(Y))
   period_agg <- period1 <- NULL
@@ -83,7 +78,7 @@ linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
   setnames(quantile, names(quantile)[ncol(quantile)], "quantile")
   if (ncol(quantile)>1) setkeyv(quantile, head(names(quantile), -1))
   threshold <- copy(quantile)
-  threshold[, threshold := p / 100 * quantile]
+  threshold[, threshold := percentage / 100 * quantile]
   threshold[, quantile := NULL]
 
   rmpgap_id <- id
@@ -117,7 +112,7 @@ linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
                                               wght = weight[indj],
                                               sort = sort[indj],
                                               ind = ind[indj],
-                                              percentag = p,
+                                              percentag = percentage,
                                               order_quants = order_quant,
                                               quant_val = rown[["quantile"]])
 
@@ -145,7 +140,7 @@ linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
                                                   wght = weight[indj],
                                                   sort = sort[indj],
                                                   ind = ind0[indj],
-                                                  percentag = p,
+                                                  percentag = percentage,
                                                   order_quants = order_quant,
                                                   quant_val = rown[["quantile"]])
                            if (!is.null(period)) {
