@@ -9,7 +9,7 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                          countryX = NULL, periodX = NULL, 
                          X_ID_level1 = NULL, ind_gr = NULL,
                          g = NULL, q = NULL, datasetX = NULL,
-                         percentage = 60, order_quant = 50,
+                         percentage = 60, order_quant = 50L,
                          alpha = 20, use.estVar = FALSE,
                          withperiod = TRUE, netchanges = TRUE,
                          confidence = .95, outp_lin = FALSE,
@@ -23,28 +23,13 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
   type <- tolower(type)
   type <- match.arg(type, all_choices, length(type)>1) 
 
-  # check 'p'
-  p <- percentage
-  if(length(p) != 1 | any(!is.numeric(p) | p < 0 | p > 100)) {
-         stop("'percentage' must be a numeric value in [0, 100]")
-     } else p <- percentage[1]
-
-  # check 'order_quant'
-
-  oq <- order_quant
-   if(length(oq) != 1 | any(!is.numeric(oq) | oq < 0 | oq > 100)) {
-          stop("'order_quant' must be a numeric value in [0, 100]")
-      } else order_quant <- order_quant[1]
-
-  if(length(alpha) != 1 | any(!is.numeric(alpha) | alpha < 0 | alpha > 100)) {
-         stop("'alpha' must be a numeric value in [0, 100]")  }
- 
-  if (length(netchanges) != 1 | !any(is.logical(netchanges))) stop("'netchanges' must be logical")
-  if (length(withperiod) != 1 | !any(is.logical(withperiod))) stop("'withperiod' must be logical")
-  if (length(use.estVar) != 1 | !any(is.logical(use.estVar))) stop("'use.estVar' must be logical")
-
-  if(length(confidence) != 1 | any(!is.numeric(confidence) | confidence < 0 | confidence > 1)) {
-         stop("'confidence' must be a numeric value in [0, 1]")  }
+  p <- check_var(vars = percentage, varn = "percentage", varntype = "numeric0100") 
+  order_quant <- check_var(vars = order_quant, varn = "order_quant", varntype = "integer0100") 
+  alpha <- check_var(vars = alpha, varn = "alpha", varntype = "numeric0100") 
+  netchanges <- check_var(vars = netchanges, varn = "netchanges", varntype = "logical") 
+  withperiod <- check_var(vars = withperiod, varn = "withperiod", varntype = "logical") 
+  use.estVar <- check_var(vars = use.estVar, varn = "use.estVar", varntype = "logical") 
+  confidence <- check_var(vars = confidence, varn = "confidence", varntype = "numeric01") 
 
   if (checking){
          if(!is.null(X)) {
@@ -134,15 +119,19 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
          
         if(!is.null(X)) {
               X <- check_var(vars = X, varn = "X", dataset = datasetX,
-                             check.names = TRUE, isnumeric = TRUE,
-                             grepls = "__")
+                             check.names = TRUE, isnumeric = TRUE, grepls = "__",
+                             dif_name = c(names(period), names(country), names(H),
+                                           names(PSU), names(ID_level1), "w_final",
+                                           "w_design", "g", "q"))
               Xnrow <- nrow(X)
            
            
-             ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
+              ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
                                  dataset = datasetX, ncols = 1,
                                  Xnrow = Xnrow, ischaracter = TRUE,
-                                 dif_name = c(names(period), names(country)))
+                                 dif_name = c(names(period), names(country), names(H),
+                                              names(PSU), names(ID_level1), "w_final",
+                                              names(X), "w_design", "g", "q"))
            
              g <- check_var(vars = g, varn = "g", dataset = datasetX,
                             ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
@@ -164,7 +153,7 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                                   mustbedefined = !is.null(period),
                                   duplicatednames = TRUE, varnout = "period",
                                   varname = names(period), country = country,
-                                  countryX = countryX)
+                                  countryX = countryX, periods = period)
            
              X_ID_level1 <- check_var(vars = X_ID_level1, varn = "X_ID_level1",
                                       dataset = datasetX, ncols = 1, Xnrow = Xnrow,
@@ -378,9 +367,9 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                        data.table(DT1[i, nos, with = FALSE],
                                   res <- residual_est(Y = DT1[i, namesY2, with = FALSE],
                                                       X = DT1[i, names(X), with = FALSE],
-                                                      weight = DT1[i, "w_design", with = FALSE],
-                                                      q = DT1[i, "q", with = FALSE],
-                                                      dataset = NULL, checking = FALSE)))
+                                                      weight = DT1[i][["w_design"]],
+                                                      q = DT1[i][["q"]], dataset = NULL,
+                                                      checking = FALSE)))
  
         res <- rbindlist(res)
         setnames(res, namesY2, namesY2w)
