@@ -32,13 +32,13 @@ vardom <- function(Y, H, PSU, w_final,
                    outp_res = FALSE) {
 
   ### Checking
-  if (length(fh_zero) != 1 | !any(is.logical(fh_zero))) stop("'fh_zero' must be logical")
-  if (length(PSU_level) != 1 | !any(is.logical(PSU_level))) stop("'PSU_level' must be logical")
-  if (length(percentratio) != 1 | !any(is.numeric(percentratio) | percentratio > 0)) stop("'percentratio' must be a positive numeric value")
-  if (length(outp_lin) != 1 | !any(is.logical(outp_lin))) stop("'outp_lin' must be logical")
-  if (length(outp_res) != 1 | !any(is.logical(outp_res))) stop("'outp_res' must be logical")
-  if(length(confidence) != 1 | any(!is.numeric(confidence) | confidence < 0 | confidence > 1)) {
-         stop("'confidence' must be a numeric value in [0, 1]")  }
+
+  fh_zero <- check_var(vars = fh_zero, varn = "fh_zero", varntype = "logical") 
+  PSU_level <- check_var(vars = PSU_level, varn = "PSU_level", varntype = "logical") 
+  outp_lin <- check_var(vars = outp_lin, varn = "outp_lin", varntype = "logical") 
+  outp_res <- check_var(vars = outp_res, varn = "outp_res", varntype = "logical") 
+  percentratio <- check_var(vars = percentratio, varn = "percentratio", varntype = "pinteger") 
+  confidence <- check_var(vars = confidence, varn = "confidence", varntype = "numeric01") 
 
   Y <- check_var(vars = Y, varn = "Y", dataset = dataset,
                  check.names = TRUE, isnumeric = TRUE, grepls = "__")
@@ -84,12 +84,14 @@ vardom <- function(Y, H, PSU, w_final,
   if (!is.null(X)) {
          X <- check_var(vars = X, varn = "X", dataset = dataset,
                         check.names = TRUE, Ynrow = Ynrow,
-                        isnumeric = TRUE, grepls = "__")
+                        isnumeric = TRUE, grepls = "__",
+                        dif_name = c(names(period), "g", "q"))
          Xnrow <- nrow(X)
 
          ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
                              dataset = dataset, ncols = 1, Xnrow = Xnrow,
-                             ischaracter = TRUE, dif_name = c(names(period)))
+                             ischaracter = TRUE,
+                             dif_name = c(names(period), names(X), "g", "q"))
 
          g <- check_var(vars = g, varn = "g", dataset = dataset,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
@@ -101,7 +103,6 @@ vardom <- function(Y, H, PSU, w_final,
     }
   dataset <- NULL
 
-
   # N_h
   if (!is.null(N_h)) {
       N_h <- data.table(N_h)
@@ -125,8 +126,11 @@ vardom <- function(Y, H, PSU, w_final,
 
   ### Calculation
 
+
   # Domains
-  if (!is.null(Dom)) Y1 <- domain(Y, Dom) else Y1 <- Y
+  if (!is.null(Dom)) Y1 <- domain(Y = Y, D = Dom,
+                                  dataset = NULL,
+                                  checking = FALSE) else Y1 <- Y
   Y <- NULL
   n_nonzero <- copy(Y1)
   if (!is.null(period)){ n_nonzero <- data.table(period, n_nonzero)
@@ -138,6 +142,7 @@ vardom <- function(Y, H, PSU, w_final,
                                                           sum(as.integer(abs(x) > .Machine$double.eps))),
                                                          .SDcols = names(Y1)]
 
+
   sar_nr <- respondent_count <- pop_size <- NULL
   nhs <- data.table(respondent_count = 1, pop_size = w_final)
   if (!is.null(period)) nhs <- data.table(period, nhs)
@@ -163,16 +168,19 @@ vardom <- function(Y, H, PSU, w_final,
   if (!is.null(period)) idper <- data.table(idper, period)
 
   if (!is.null(Z)) {
-    if (!is.null(Dom)) Z1 <- domain(Z, Dom) else Z1 <- Z
+    if (!is.null(Dom)) Z1 <- domain(Y = Z, D = Dom,
+                                    dataset = NULL,
+                                    checking = FALSE) else Z1 <- Z
     if (is.null(period)) {
-          Y2 <- lin.ratio(Y1, Z1, w_final, Dom = NULL,
+          Y2 <- lin.ratio(Y = Y1, Z = Z1, weight = w_final, Dom = NULL,
                           dataset = NULL, percentratio = percentratio,
                           checking = FALSE)
         } else {
             periodap <- do.call("paste", c(as.list(period), sep = "_"))
             lin1 <- lapply(split(Y1[, .I], periodap), function(i)
                             data.table(sar_nr = i,
-                                   lin.ratio(Y1[i], Z1[i], w_final[i],
+                                   lin.ratio(Y = Y1[i], Z = Z1[i],
+                                             weight = w_final[i],
                                              Dom = NULL, dataset = NULL,
                                              percentratio = percentratio,
                                              checking = FALSE)))
