@@ -16,11 +16,10 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
  
   ### Checking
 
-  if (length(outp_lin) != 1 | !any(is.logical(outp_lin))) stop("'outp_lin' must be logical")
-  if (length(outp_res) != 1 | !any(is.logical(outp_res))) stop("'outp_res' must be logical")
-  if (length(percentratio) != 1 | !any(is.numeric(percentratio) | percentratio > 0)) stop("'percentratio' must be a positive numeric value")
-  if(length(confidence) != 1 | any(!is.numeric(confidence) | confidence < 0 | confidence > 1)) {
-         stop("'confidence' must be a numeric value in [0, 1]")  }
+  outp_lin <- check_var(vars = outp_lin, varn = "outp_lin", varntype = "logical") 
+  outp_res <- check_var(vars = outp_res, varn = "outp_res", varntype = "logical") 
+  percentratio <- check_var(vars = percentratio, varn = "percentratio", varntype = "pinteger") 
+  confidence <- check_var(vars = confidence, varn = "confidence", varntype = "numeric01") 
 
   Y <- check_var(vars = Y, varn = "Y", dataset = dataset,
                  check.names = TRUE, isnumeric = TRUE, grepls = "__")
@@ -66,12 +65,13 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
   if (!is.null(X)) {
          X <- check_var(vars = X, varn = "X", dataset = dataset,
                         check.names = TRUE, Ynrow = Ynrow,
-                        isnumeric = TRUE, grepls = "__")
+                        isnumeric = TRUE, grepls = "__",
+                        dif_name = c(names(period), "g", "q"))
          Xnrow <- nrow(X)
 
          ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
                              dataset = dataset, ncols = 1, Xnrow = Xnrow,
-                             ischaracter = TRUE, dif_name = c(names(period)))
+                             ischaracter = TRUE, dif_name = c(names(period), "g", "q"))
 
          g <- check_var(vars = g, varn = "g", dataset = dataset,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
@@ -130,7 +130,9 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
   ### Calculation
       
   # Domains
-  if (!is.null(Dom)) Y1 <- domain(Y, Dom) else Y1 <- Y
+  if (!is.null(Dom)) Y1 <- domain(Y = Y, D = Dom,
+                                  dataset = NULL,
+                                  checking = FALSE) else Y1 <- Y
 
   n_nonzero <- copy(Y1)
   if (!is.null(period)){ n_nonzero <- data.table(period, n_nonzero) 
@@ -167,15 +169,20 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
 
   Z1 <- NULL
   if (!is.null(Z)) {
-    if (!is.null(Dom)) Z1 <- domain(Z, Dom) else Z1 <- Z
+    if (!is.null(Dom)) Z1 <- domain(Y = Z, D = Dom,
+                                    dataset = NULL,
+                                    checking = FALSE) else Z1 <- Z
     if (is.null(period)) {
-          Y2 <- lin.ratio(Y1, Z1, w_final, Dom = NULL)
-          Y2a <- lin.ratio(Y1, Z1, w_design, Dom = NULL)
+          Y2 <- lin.ratio(Y = Y1, Z = Z1, weight = w_final,
+                          Dom = NULL, dataset = NULL,
+                          percentratio = percentratio,
+                          checking = FALSE)
         } else {
             periodap <- do.call("paste", c(as.list(period), sep = "_"))
             lin1 <- lapply(split(Y1[, .I], periodap), function(i)
                             data.table(sar_nr = i, 
-                                       lin.ratio(Y1[i], Z1[i], w_final[i],
+                                       lin.ratio(Y = Y1[i], Z = Z1[i],
+                                                 weight = w_final[i],
                                                  Dom = NULL, dataset = NULL,
                                                  percentratio = percentratio,
                                                  checking = FALSE)))
